@@ -17,7 +17,7 @@ class Page(Base):
     url = sa.Column('url', sa.String(2000), nullable=False)
     url_hash = sa.Column('url_hash', sa.String(128), nullable=False)
     uuid = sa.Column('uuid', sa.String(36), default=uuid4, nullable=False)
-    created_date = sa.Column('created_date', sa.DateTime, default=datetime.now, nullable=False)
+    created_date = sa.Column('created_date', sa.DateTime, default=datetime.utcnow, nullable=False)
 
     last_review_date = sa.Column('last_review_date', sa.DateTime, nullable=True)
 
@@ -65,16 +65,18 @@ class Page(Base):
                 sa.func.month(Review.completed_date),
                 sa.func.day(Review.completed_date),
             ) \
+            .order_by(Review.completed_date) \
             .all()
 
-        result = {}
+        result = []
 
         for day in violations:
             dt = "%d-%d-%d" % (day.year, day.month, day.day)
-            result[dt] = {
+            result.append({
+                "completedAt": dt,
                 "violation_count": int(day.violation_count),
                 "violation_points": int(day.violation_points)
-            }
+            })
 
         return result
 
