@@ -8,6 +8,23 @@ from holmes.validators.base import Validator
 
 class LinkWithRelCanonicalValidator(Validator):
 
+    @classmethod
+    def get_absent_meta_canonical_message(cls, value):
+        url = 'https://support.google.com/webmasters/answer/139394?hl=en'
+        return 'As can be seen in this page <a href="%s">About ' \
+               'rel="canonical"</a>, it\'s a good practice to ' \
+               'include rel="canonical" urls in the pages for ' \
+               'your website.' % url
+
+    @classmethod
+    def get_violation_definitions(cls):
+        return {
+            'absent.meta.canonical': {
+                'title': 'Link with rel="canonical" not found',
+                'description': cls.get_absent_meta_canonical_message
+            }
+        }
+
     def validate(self):
         if not self.config.FORCE_CANONICAL:
             # Only pages with query string parameters
@@ -19,15 +36,9 @@ class LinkWithRelCanonicalValidator(Validator):
         canonical = [item for item in head if item.get('rel') == 'canonical']
 
         if not canonical:
-            url = 'https://support.google.com/webmasters/answer/139394?hl=en'
-
             self.add_violation(
                 key='absent.meta.canonical',
-                title='Link with rel="canonical" not found',
-                description='As can be seen in this page <a href="%s">About '
-                            'rel="canonical"</a>, it\'s a good practice to '
-                            'include rel="canonical" urls in the pages for '
-                            'your website.' % (url),
+                value=None,
                 points=30
             )
 
